@@ -206,10 +206,15 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000, for
             as datin
 
     appenddim: append dnamsel with the inner dimensions of the data input
-               streams when possible. This will generally lead to an increased
-               performance. This option needs be supported by the func.
+               streams when possible (ie. limited by the maxmembytes option).
+               This will generally lead to an increased performance, but more
+               memory consumption.  This option needs be supported by the function!
+               For example in the case of using interp1d (see example
+               seltimeobs.py), you need to specify the axis=0 option, so that
+               the function is applied along the slowest changing dimensions
+               (inner dimensions; dimensions in front). 
 
-    maxmembytes: the maximum amount of bytes that is allowed for the buffers to be read/written from/to the input/output data streams. 
+    maxmembytes: The option is applicable when using appenddim. The maximum amount of bytes that is allowed for the buffers to be read/written from/to the input/output data streams. 
     """
 
     # track the dimensions to be selected when multiples are given
